#
# This script contains customizations of the Tomcat environment variables. It is
# automatically picked up by /opt/hibox/tomcat9/bin/catalina.sh if it exists.
#
# Modifications to this file are permitted; it will not be overwritten when the
# `hibox-tomcat9` package gets updated. If you ever wish to revert to the
# original/package-provided version, just copy
# /opt/hibox/tomcat9/skel/bin/setenv.sh` over this file.
#

# Can be connected to from e.g. IntelliJ for remote-debugging a local Tomcat
# process.
TOMCAT_DEBUGGER_PORT=9099

# Set to 'y' to halt startup, waiting on debugger to be attached
TOMCAT_DEBUGGER_SUSPEND=n

# Max memory to use for the Tomcat process (-Xmx parameter)
TOMCAT_HEAP_SIZE=4096M

# Enable debugger
CATALINA_OPTS="
    -Xdebug -Xrunjdwp:transport=dt_socket,address=${TOMCAT_DEBUGGER_PORT},server=y,suspend=${TOMCAT_DEBUGGER_SUSPEND}
    "

# Tomcat base Java options
CATALINA_OPTS="${CATALINA_OPTS} \
    -Djava.awt.headless=true \
    -Djava.net.preferIPv4Stack=true \
    -XX:+HeapDumpOnOutOfMemoryError \
    -XX:HeapDumpPath=/tmp/ \
    -Dsun.net.client.defaultConnectTimeout=10000 \
    -Dsun.net.client.defaultReadTimeout=15000"

# Uncomment to enable Prometheus metrics
#CATALINA_OPTS="${CATALINA_OPTS} \
#    -Dhibox.metrics.micrometer.prometheus=0.0.0.0:8083"

# Enable custom heap size
CATALINA_OPTS="${CATALINA_OPTS} -Xmx${TOMCAT_HEAP_SIZE}"

# Use G1GC garbage collector
CATALINA_OPTS="${CATALINA_OPTS} -XX:+UseG1GC"

# Java 8: Uncomment to enable verbose GC logging with rotation:
#CATALINA_OPTS="${CATALINA_OPTS} \
#    -XX:+PrintGCDetails \
#    -XX:+PrintGCDateStamps \
#    -XX:+PrintGCApplicationStoppedTime \
#    -XX:+PrintAdaptiveSizePolicy \
#    -XX:+UseGCLogFileRotation \
#    -XX:NumberOfGCLogFiles=20 \
#    -XX:GCLogFileSize=20M \
#    -Xloggc:${CATALINA_BASE}logs/gc-%t.log"

# Java 9+: Uncomment to enable verbose GC logging with rotation:
#CATALINA_OPTS="${CATALINA_OPTS} \
#    -Xlog:gc*:file=${CATALINA_BASE}/logs/gc-%t.log:time,level,tags:filecount=20,filesize=20M"

# Workaround for libtcnative-1 not being picked up on Eclipse Temurin. More
# details: https://github.com/adoptium/adoptium-support/issues/485
CATALINA_OPTS="${CATALINA_OPTS} -Djava.library.path=/usr/lib/x86_64-linux-gnu/jni:/lib/x86_64-linux-gnu:/usr/lib/x86_64-linux-gnu:/usr/lib/jni:/lib:/usr/lib"

# Trim extra whitespace from the above
CATALINA_OPTS=$(echo $CATALINA_OPTS | xargs)

CATALINA_PID="${CATALINA_BASE}/bin/catalina.pid"

# Workaround for command which can fail in `startup.sh`
set +e
